<?php

namespace Drupal\decoupled_kit_redirect\Resource;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\decoupled_kit\DecoupledKit;
use Drupal\jsonapi\ResourceResponse;
use Drupal\jsonapi_resources\Resource\EntityQueryResourceBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Processes a request for a collection of featured nodes.
 *
 * @internal
 */
final class Redirect extends EntityQueryResourceBase implements ContainerInjectionInterface {

  /**
   * Constructs a Blocks object.
   */
  public function __construct(
    private readonly DecoupledKit $decoupledKit,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('decoupled_kit')
    );
  }

  /**
   * Process the resource request.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return \Drupal\jsonapi\ResourceResponse
   *   The response.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function process(Request $request): ResourceResponse {
    $path = $this->decoupledKit->checkPath($request, FALSE);

    $entity_query = $this->getEntityQuery('redirect')
      ->accessCheck(FALSE)
      ->condition('redirect_source.path', ltrim($path, '/'));

    $cacheability = new CacheableMetadata();
    $cacheability->addCacheContexts(['url.query_args:current_page']);

    $data = $this->loadResourceObjectDataFromEntityQuery($entity_query, $cacheability);
    $response = $this->createJsonapiResponse($data, $request);
    $response->addCacheableDependency($cacheability);

    return $response;
  }

}
